@@ -19,7 +19,7 @@ import sys
 
 def read_data():
     try:
-        data= pd.read_csv('MdsSoftwareSetup533/base_data.csv',index_col=False)
+        data= pd.read_csv('base_data.csv',index_col=False)
     except FileNotFoundError:
         print("Invalid file address")
         sys.exit(0)
